@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2004-2010 John E. Davis
+Copyright (C) 2004-2014 John E. Davis
 
 This file is part of the S-Lang Library.
 
@@ -372,6 +372,7 @@ SLcurses_Window_Type *SLcurses_initscr (void)
    SLtt_set_mono (SLCURSES_EXTRACT_COLOR(A_UNDERLINE), NULL, SLTT_ULINE_MASK);
    SLtt_set_mono (SLCURSES_EXTRACT_COLOR(A_REVERSE), NULL, SLTT_REV_MASK);
    /* SLtt_set_mono (SLCURSES_EXTRACT_COLOR(A_BLINK), NULL, SLTT_BLINK_MASK); */
+   /* SLtt_set_mono (SLCURSES_EXTRACT_COLOR(A_ITALIC), NULL, SLTT_ITALIC_MASK); */
    SLtt_set_mono ((SLCURSES_EXTRACT_COLOR(A_BOLD|A_UNDERLINE)), NULL, SLTT_ULINE_MASK|SLTT_BOLD_MASK);
    SLtt_set_mono ((SLCURSES_EXTRACT_COLOR(A_REVERSE|A_UNDERLINE)), NULL, SLTT_ULINE_MASK|SLTT_REV_MASK);
 
@@ -505,7 +506,7 @@ SLcurses_Window_Type *SLcurses_newwin (unsigned int nrows, unsigned int ncols,
    if (ncols == 0)
      ncols = (unsigned int) SLtt_Screen_Cols - c;
 
-   lines = (SLcurses_Cell_Type **) SLmalloc (nrows * sizeof (SLcurses_Cell_Type *));
+   lines = (SLcurses_Cell_Type **) _SLcalloc (nrows, sizeof (SLcurses_Cell_Type *));
    if (lines == NULL)
      {
 	SLcurses_delwin (win);
@@ -528,7 +529,7 @@ SLcurses_Window_Type *SLcurses_newwin (unsigned int nrows, unsigned int ncols,
      {
 	SLcurses_Cell_Type *b;
 
-	b = (SLcurses_Cell_Type *) SLmalloc (ncols * sizeof (SLcurses_Cell_Type));
+	b = (SLcurses_Cell_Type *) _SLcalloc (ncols, sizeof (SLcurses_Cell_Type));
 	if (b == NULL)
 	  {
 	     SLcurses_delwin (win);
@@ -1125,7 +1126,7 @@ SLcurses_Window_Type *SLcurses_subwin (SLcurses_Window_Type *orig,
    sw->_maxx = (begin_x + ncols) - 1;
    sw->_maxy = (begin_y + nlines) - 1;
 
-   sw->lines = (SLcurses_Cell_Type **) SLmalloc (nlines * sizeof (SLcurses_Cell_Type *));
+   sw->lines = (SLcurses_Cell_Type **) _SLcalloc (nlines, sizeof (SLcurses_Cell_Type *));
    if (sw->lines == NULL)
      {
 	SLcurses_delwin (sw);
